Class: Aws::Route53RecoveryControlConfig::Waiters::ClusterCreated
- Inherits:
-
Object
- Object
- Aws::Route53RecoveryControlConfig::Waiters::ClusterCreated
- Defined in:
- lib/aws-sdk-route53recoverycontrolconfig/waiters.rb,
sig/waiters.rbs
Overview
Wait until a cluster is created
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ ClusterCreated
constructor
A new instance of ClusterCreated.
-
#wait(params = {}) ⇒ Types::DescribeClusterResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ ClusterCreated
Returns a new instance of ClusterCreated.
90 91 |
# File 'lib/aws-sdk-route53recoverycontrolconfig/waiters.rb', line 90
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
127 128 129 |
# File 'lib/aws-sdk-route53recoverycontrolconfig/waiters.rb', line 127 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeClusterResponse
Returns a response object which responds to the following methods:
- #cluster => Types::Cluster
122 |
# File 'lib/aws-sdk-route53recoverycontrolconfig/waiters.rb', line 122
def wait: (
|