Class: Aws::Route53RecoveryControlConfig::Waiters::ControlPanelDeleted
- Inherits:
-
Object
- Object
- Aws::Route53RecoveryControlConfig::Waiters::ControlPanelDeleted
- Defined in:
- lib/aws-sdk-route53recoverycontrolconfig/waiters.rb,
sig/waiters.rbs
Overview
Wait until a control panel is deleted
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ ControlPanelDeleted
constructor
A new instance of ControlPanelDeleted.
-
#wait(params = {}) ⇒ Types::DescribeControlPanelResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ ControlPanelDeleted
Returns a new instance of ControlPanelDeleted.
239 240 |
# File 'lib/aws-sdk-route53recoverycontrolconfig/waiters.rb', line 239
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
275 276 277 |
# File 'lib/aws-sdk-route53recoverycontrolconfig/waiters.rb', line 275 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeControlPanelResponse
Returns a response object which responds to the following methods:
- #control_panel => Types::ControlPanel
270 |
# File 'lib/aws-sdk-route53recoverycontrolconfig/waiters.rb', line 270
def wait: (
|