Class: Aws::Route53RecoveryControlConfig::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Route53RecoveryControlConfig::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-route53recoverycontrolconfig/client.rb
Overview
An API client for Route53RecoveryControlConfig. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::Route53RecoveryControlConfig::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_cluster(params = {}) ⇒ Types::CreateClusterResponse
Create a new cluster.
-
#create_control_panel(params = {}) ⇒ Types::CreateControlPanelResponse
Creates a new control panel.
-
#create_routing_control(params = {}) ⇒ Types::CreateRoutingControlResponse
Creates a new routing control.
-
#create_safety_rule(params = {}) ⇒ Types::CreateSafetyRuleResponse
Creates a safety rule in a control panel.
-
#delete_cluster(params = {}) ⇒ Struct
Delete a cluster.
-
#delete_control_panel(params = {}) ⇒ Struct
Deletes a control panel.
-
#delete_routing_control(params = {}) ⇒ Struct
Deletes a routing control.
-
#delete_safety_rule(params = {}) ⇒ Struct
Deletes a safety rule.
-
#describe_cluster(params = {}) ⇒ Types::DescribeClusterResponse
Display the details about a cluster.
-
#describe_control_panel(params = {}) ⇒ Types::DescribeControlPanelResponse
Displays details about a control panel.
-
#describe_routing_control(params = {}) ⇒ Types::DescribeRoutingControlResponse
Displays details about a routing control.
-
#describe_safety_rule(params = {}) ⇒ Types::DescribeSafetyRuleResponse
Returns information about a safety rule.
-
#get_resource_policy(params = {}) ⇒ Types::GetResourcePolicyResponse
Get information about the resource policy for a cluster.
-
#list_associated_route_53_health_checks(params = {}) ⇒ Types::ListAssociatedRoute53HealthChecksResponse
Returns an array of all Amazon Route 53 health checks associated with a specific routing control.
-
#list_clusters(params = {}) ⇒ Types::ListClustersResponse
Returns an array of all the clusters in an account.
-
#list_control_panels(params = {}) ⇒ Types::ListControlPanelsResponse
Returns an array of control panels in an account or in a cluster.
-
#list_routing_controls(params = {}) ⇒ Types::ListRoutingControlsResponse
Returns an array of routing controls for a control panel.
-
#list_safety_rules(params = {}) ⇒ Types::ListSafetyRulesResponse
List the safety rules (the assertion rules and gating rules) that you’ve defined for the routing controls in a control panel.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for a resource.
-
#tag_resource(params = {}) ⇒ Struct
Adds a tag to a resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes a tag from a resource.
-
#update_cluster(params = {}) ⇒ Types::UpdateClusterResponse
Updates a cluster.
-
#update_control_panel(params = {}) ⇒ Types::UpdateControlPanelResponse
Updates a control panel.
-
#update_routing_control(params = {}) ⇒ Types::UpdateRoutingControlResponse
Updates a routing control.
-
#update_safety_rule(params = {}) ⇒ Types::UpdateSafetyRuleResponse
Update a safety rule (an assertion rule or gating rule).
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
-
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-route53recoverycontrolconfig/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1705 1706 1707 |
# File 'lib/aws-sdk-route53recoverycontrolconfig/client.rb', line 1705 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1708 1709 1710 |
# File 'lib/aws-sdk-route53recoverycontrolconfig/client.rb', line 1708 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1555 1556 1557 1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 1569 1570 1571 |
# File 'lib/aws-sdk-route53recoverycontrolconfig/client.rb', line 1555 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Route53RecoveryControlConfig') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-route53recoverycontrolconfig' context[:gem_version] = '1.58.0' Seahorse::Client::Request.new(handlers, context) end |
#create_cluster(params = {}) ⇒ Types::CreateClusterResponse
Create a new cluster. A cluster is a set of redundant Regional endpoints against which you can run API calls to update or get the state of one or more routing controls. Each cluster has a name, status, Amazon Resource Name (ARN), and an array of the five cluster endpoints (one for each supported Amazon Web Services Region) that you can use with API calls to the cluster data plane.
532 533 534 535 |
# File 'lib/aws-sdk-route53recoverycontrolconfig/client.rb', line 532 def create_cluster(params = {}, = {}) req = build_request(:create_cluster, params) req.send_request() end |
#create_control_panel(params = {}) ⇒ Types::CreateControlPanelResponse
Creates a new control panel. A control panel represents a group of routing controls that can be changed together in a single transaction. You can use a control panel to centrally view the operational status of applications across your organization, and trigger multi-app failovers in a single transaction, for example, to fail over an Availability Zone or Amazon Web Services Region.
590 591 592 593 |
# File 'lib/aws-sdk-route53recoverycontrolconfig/client.rb', line 590 def create_control_panel(params = {}, = {}) req = build_request(:create_control_panel, params) req.send_request() end |
#create_routing_control(params = {}) ⇒ Types::CreateRoutingControlResponse
Creates a new routing control.
A routing control has one of two states: ON and OFF. You can map the routing control state to the state of an Amazon Route 53 health check, which can be used to control traffic routing.
To get or update the routing control state, see the Recovery Cluster (data plane) API actions for Amazon Route 53 Application Recovery Controller.
649 650 651 652 |
# File 'lib/aws-sdk-route53recoverycontrolconfig/client.rb', line 649 def create_routing_control(params = {}, = {}) req = build_request(:create_routing_control, params) req.send_request() end |
#create_safety_rule(params = {}) ⇒ Types::CreateSafetyRuleResponse
Creates a safety rule in a control panel. Safety rules let you add safeguards around changing routing control states, and for enabling and disabling routing controls, to help prevent unexpected outcomes.
There are two types of safety rules: assertion rules and gating rules.
Assertion rule: An assertion rule enforces that, when you change a routing control state, that a certain criteria is met. For example, the criteria might be that at least one routing control state is On after the transaction so that traffic continues to flow to at least one cell for the application. This ensures that you avoid a fail-open scenario.
Gating rule: A gating rule lets you configure a gating routing control as an overall “on/off” switch for a group of routing controls. Or, you can configure more complex gating scenarios, for example by configuring multiple gating routing controls.
For more information, see [Safety rules] in the Amazon Route 53 Application Recovery Controller Developer Guide.
[1]: docs.aws.amazon.com/r53recovery/latest/dg/routing-control.safety-rules.html
764 765 766 767 |
# File 'lib/aws-sdk-route53recoverycontrolconfig/client.rb', line 764 def create_safety_rule(params = {}, = {}) req = build_request(:create_safety_rule, params) req.send_request() end |
#delete_cluster(params = {}) ⇒ Struct
Delete a cluster.
785 786 787 788 |
# File 'lib/aws-sdk-route53recoverycontrolconfig/client.rb', line 785 def delete_cluster(params = {}, = {}) req = build_request(:delete_cluster, params) req.send_request() end |
#delete_control_panel(params = {}) ⇒ Struct
Deletes a control panel.
806 807 808 809 |
# File 'lib/aws-sdk-route53recoverycontrolconfig/client.rb', line 806 def delete_control_panel(params = {}, = {}) req = build_request(:delete_control_panel, params) req.send_request() end |
#delete_routing_control(params = {}) ⇒ Struct
Deletes a routing control.
827 828 829 830 |
# File 'lib/aws-sdk-route53recoverycontrolconfig/client.rb', line 827 def delete_routing_control(params = {}, = {}) req = build_request(:delete_routing_control, params) req.send_request() end |
#delete_safety_rule(params = {}) ⇒ Struct
Deletes a safety rule.
/>
850 851 852 853 |
# File 'lib/aws-sdk-route53recoverycontrolconfig/client.rb', line 850 def delete_safety_rule(params = {}, = {}) req = build_request(:delete_safety_rule, params) req.send_request() end |
#describe_cluster(params = {}) ⇒ Types::DescribeClusterResponse
Display the details about a cluster. The response includes the cluster name, endpoints, status, and Amazon Resource Name (ARN).
The following waiters are defined for this operation (see #wait_until for detailed usage):
* cluster_created
* cluster_deleted
891 892 893 894 |
# File 'lib/aws-sdk-route53recoverycontrolconfig/client.rb', line 891 def describe_cluster(params = {}, = {}) req = build_request(:describe_cluster, params) req.send_request() end |
#describe_control_panel(params = {}) ⇒ Types::DescribeControlPanelResponse
Displays details about a control panel.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* control_panel_created
* control_panel_deleted
930 931 932 933 |
# File 'lib/aws-sdk-route53recoverycontrolconfig/client.rb', line 930 def describe_control_panel(params = {}, = {}) req = build_request(:describe_control_panel, params) req.send_request() end |
#describe_routing_control(params = {}) ⇒ Types::DescribeRoutingControlResponse
Displays details about a routing control. A routing control has one of two states: ON and OFF. You can map the routing control state to the state of an Amazon Route 53 health check, which can be used to control routing.
To get or update the routing control state, see the Recovery Cluster (data plane) API actions for Amazon Route 53 Application Recovery Controller.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* routing_control_created
* routing_control_deleted
974 975 976 977 |
# File 'lib/aws-sdk-route53recoverycontrolconfig/client.rb', line 974 def describe_routing_control(params = {}, = {}) req = build_request(:describe_routing_control, params) req.send_request() end |
#describe_safety_rule(params = {}) ⇒ Types::DescribeSafetyRuleResponse
Returns information about a safety rule.
1025 1026 1027 1028 |
# File 'lib/aws-sdk-route53recoverycontrolconfig/client.rb', line 1025 def describe_safety_rule(params = {}, = {}) req = build_request(:describe_safety_rule, params) req.send_request() end |
#get_resource_policy(params = {}) ⇒ Types::GetResourcePolicyResponse
Get information about the resource policy for a cluster.
1052 1053 1054 1055 |
# File 'lib/aws-sdk-route53recoverycontrolconfig/client.rb', line 1052 def get_resource_policy(params = {}, = {}) req = build_request(:get_resource_policy, params) req.send_request() end |
#list_associated_route_53_health_checks(params = {}) ⇒ Types::ListAssociatedRoute53HealthChecksResponse
Returns an array of all Amazon Route 53 health checks associated with a specific routing control.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1091 1092 1093 1094 |
# File 'lib/aws-sdk-route53recoverycontrolconfig/client.rb', line 1091 def list_associated_route_53_health_checks(params = {}, = {}) req = build_request(:list_associated_route_53_health_checks, params) req.send_request() end |
#list_clusters(params = {}) ⇒ Types::ListClustersResponse
Returns an array of all the clusters in an account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1133 1134 1135 1136 |
# File 'lib/aws-sdk-route53recoverycontrolconfig/client.rb', line 1133 def list_clusters(params = {}, = {}) req = build_request(:list_clusters, params) req.send_request() end |
#list_control_panels(params = {}) ⇒ Types::ListControlPanelsResponse
Returns an array of control panels in an account or in a cluster.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1177 1178 1179 1180 |
# File 'lib/aws-sdk-route53recoverycontrolconfig/client.rb', line 1177 def list_control_panels(params = {}, = {}) req = build_request(:list_control_panels, params) req.send_request() end |
#list_routing_controls(params = {}) ⇒ Types::ListRoutingControlsResponse
Returns an array of routing controls for a control panel. A routing control is an Amazon Route 53 Application Recovery Controller construct that has one of two states: ON and OFF. You can map the routing control state to the state of an Amazon Route 53 health check, which can be used to control routing.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1223 1224 1225 1226 |
# File 'lib/aws-sdk-route53recoverycontrolconfig/client.rb', line 1223 def list_routing_controls(params = {}, = {}) req = build_request(:list_routing_controls, params) req.send_request() end |
#list_safety_rules(params = {}) ⇒ Types::ListSafetyRulesResponse
List the safety rules (the assertion rules and gating rules) that you’ve defined for the routing controls in a control panel.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1285 1286 1287 1288 |
# File 'lib/aws-sdk-route53recoverycontrolconfig/client.rb', line 1285 def list_safety_rules(params = {}, = {}) req = build_request(:list_safety_rules, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for a resource.
1313 1314 1315 1316 |
# File 'lib/aws-sdk-route53recoverycontrolconfig/client.rb', line 1313 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds a tag to a resource.
1340 1341 1342 1343 |
# File 'lib/aws-sdk-route53recoverycontrolconfig/client.rb', line 1340 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes a tag from a resource.
1364 1365 1366 1367 |
# File 'lib/aws-sdk-route53recoverycontrolconfig/client.rb', line 1364 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_cluster(params = {}) ⇒ Types::UpdateClusterResponse
Updates a cluster. You can only update the network-type of a cluster.
1402 1403 1404 1405 |
# File 'lib/aws-sdk-route53recoverycontrolconfig/client.rb', line 1402 def update_cluster(params = {}, = {}) req = build_request(:update_cluster, params) req.send_request() end |
#update_control_panel(params = {}) ⇒ Types::UpdateControlPanelResponse
Updates a control panel. The only update you can make to a control panel is to change the name of the control panel.
1441 1442 1443 1444 |
# File 'lib/aws-sdk-route53recoverycontrolconfig/client.rb', line 1441 def update_control_panel(params = {}, = {}) req = build_request(:update_control_panel, params) req.send_request() end |
#update_routing_control(params = {}) ⇒ Types::UpdateRoutingControlResponse
Updates a routing control. You can only update the name of the routing control. To get or update the routing control state, see the Recovery Cluster (data plane) API actions for Amazon Route 53 Application Recovery Controller.
1480 1481 1482 1483 |
# File 'lib/aws-sdk-route53recoverycontrolconfig/client.rb', line 1480 def update_routing_control(params = {}, = {}) req = build_request(:update_routing_control, params) req.send_request() end |
#update_safety_rule(params = {}) ⇒ Types::UpdateSafetyRuleResponse
Update a safety rule (an assertion rule or gating rule). You can only update the name and the waiting period for a safety rule. To make other updates, delete the safety rule and create a new one.
1546 1547 1548 1549 |
# File 'lib/aws-sdk-route53recoverycontrolconfig/client.rb', line 1546 def update_safety_rule(params = {}, = {}) req = build_request(:update_safety_rule, params) req.send_request() end |
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
## Basic Usage
A waiter will call an API operation until:
-
It is successful
-
It enters a terminal state
-
It makes the maximum number of attempts
In between attempts, the waiter will sleep.
# polls in a loop, sleeping between attempts
client.wait_until(waiter_name, params)
## Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. You can pass configuration as the final arguments hash.
# poll for ~25 seconds
client.wait_until(waiter_name, params, {
max_attempts: 5,
delay: 5,
})
## Callbacks
You can be notified before each polling attempt and before each delay. If you throw ‘:success` or `:failure` from these callbacks, it will terminate the waiter.
started_at = Time.now
client.wait_until(waiter_name, params, {
# disable max attempts
max_attempts: nil,
# poll for 1 hour, instead of a number of attempts
before_wait: -> (attempts, response) do
throw :failure if Time.now - started_at > 3600
end
})
## Handling Errors
When a waiter is unsuccessful, it will raise an error. All of the failure errors extend from Waiters::Errors::WaiterFailed.
begin
client.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
## Valid Waiters
The following table lists the valid waiter names, the operations they call, and the default ‘:delay` and `:max_attempts` values.
| waiter_name | params | :delay | :max_attempts | | ———————– | ——————————— | ——– | ————- | | cluster_created | #describe_cluster | 5 | 26 | | cluster_deleted | #describe_cluster | 5 | 26 | | control_panel_created | #describe_control_panel | 5 | 26 | | control_panel_deleted | #describe_control_panel | 5 | 26 | | routing_control_created | #describe_routing_control | 5 | 26 | | routing_control_deleted | #describe_routing_control | 5 | 26 |
1666 1667 1668 1669 1670 |
# File 'lib/aws-sdk-route53recoverycontrolconfig/client.rb', line 1666 def wait_until(waiter_name, params = {}, = {}) w = waiter(waiter_name, ) yield(w.waiter) if block_given? # deprecated w.wait(params) end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1674 1675 1676 |
# File 'lib/aws-sdk-route53recoverycontrolconfig/client.rb', line 1674 def waiter_names waiters.keys end |